@@ -26,50 +26,49 @@ class UpdateVpcEndpointServiceAttributeRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Privatelink', '2020-04-15', 'UpdateVpcEndpointServiceAttribute','privatelink')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AutoAcceptEnabled(self):
+	def get_AutoAcceptEnabled(self): # Boolean
 		return self.get_query_params().get('AutoAcceptEnabled')
 
-	def set_AutoAcceptEnabled(self,AutoAcceptEnabled):
-		self.add_query_param('AutoAcceptEnabled',AutoAcceptEnabled)
-
-	def get_ClientToken(self):
+	def set_AutoAcceptEnabled(self, AutoAcceptEnabled):  # Boolean
+		self.add_query_param('AutoAcceptEnabled', AutoAcceptEnabled)
+	def get_ClientToken(self): # String
 		return self.get_query_params().get('ClientToken')
 
-	def set_ClientToken(self,ClientToken):
-		self.add_query_param('ClientToken',ClientToken)
-
-	def get_ConnectBandwidth(self):
+	def set_ClientToken(self, ClientToken):  # String
+		self.add_query_param('ClientToken', ClientToken)
+	def get_ConnectBandwidth(self): # Integer
 		return self.get_query_params().get('ConnectBandwidth')
 
-	def set_ConnectBandwidth(self,ConnectBandwidth):
-		self.add_query_param('ConnectBandwidth',ConnectBandwidth)
-
-	def get_ZoneAffinityEnabled(self):
+	def set_ConnectBandwidth(self, ConnectBandwidth):  # Integer
+		self.add_query_param('ConnectBandwidth', ConnectBandwidth)
+	def get_ZoneAffinityEnabled(self): # Boolean
 		return self.get_query_params().get('ZoneAffinityEnabled')
 
-	def set_ZoneAffinityEnabled(self,ZoneAffinityEnabled):
-		self.add_query_param('ZoneAffinityEnabled',ZoneAffinityEnabled)
-
-	def get_DryRun(self):
+	def set_ZoneAffinityEnabled(self, ZoneAffinityEnabled):  # Boolean
+		self.add_query_param('ZoneAffinityEnabled', ZoneAffinityEnabled)
+	def get_DryRun(self): # Boolean
 		return self.get_query_params().get('DryRun')
 
-	def set_DryRun(self,DryRun):
-		self.add_query_param('DryRun',DryRun)
+	def set_DryRun(self, DryRun):  # Boolean
+		self.add_query_param('DryRun', DryRun)
+	def get_ServiceSupportIPv6(self): # Boolean
+		return self.get_query_params().get('ServiceSupportIPv6')
 
-	def get_ServiceDescription(self):
+	def set_ServiceSupportIPv6(self, ServiceSupportIPv6):  # Boolean
+		self.add_query_param('ServiceSupportIPv6', ServiceSupportIPv6)
+	def get_ServiceDescription(self): # String
 		return self.get_query_params().get('ServiceDescription')
 
-	def set_ServiceDescription(self,ServiceDescription):
-		self.add_query_param('ServiceDescription',ServiceDescription)
-
-	def get_ServiceId(self):
+	def set_ServiceDescription(self, ServiceDescription):  # String
+		self.add_query_param('ServiceDescription', ServiceDescription)
+	def get_ServiceId(self): # String
 		return self.get_query_params().get('ServiceId')
 
-	def set_ServiceId(self,ServiceId):
-		self.add_query_param('ServiceId',ServiceId)
\ No newline at end of file
+	def set_ServiceId(self, ServiceId):  # String
+		self.add_query_param('ServiceId', ServiceId)
